Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(481)

Unified Diff: ui/views/corewm/tooltip_controller.cc

Issue 1915363002: Rename gfx::Display/Screen to display::Display/Screen in views/wm (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: more cleanups Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/corewm/tooltip_aura.cc ('k') | ui/views/corewm/tooltip_controller_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/corewm/tooltip_controller.cc
diff --git a/ui/views/corewm/tooltip_controller.cc b/ui/views/corewm/tooltip_controller.cc
index a71001719fc2fe7b4deba9cc1da79b8e5dc8f279..a45b406fec2d55d4ef847e6dbcd163c415ea9357 100644
--- a/ui/views/corewm/tooltip_controller.cc
+++ b/ui/views/corewm/tooltip_controller.cc
@@ -17,10 +17,10 @@
#include "ui/aura/client/screen_position_client.h"
#include "ui/aura/env.h"
#include "ui/aura/window.h"
+#include "ui/display/screen.h"
#include "ui/events/event.h"
#include "ui/gfx/font.h"
#include "ui/gfx/geometry/rect.h"
-#include "ui/gfx/screen.h"
#include "ui/gfx/text_elider.h"
#include "ui/views/corewm/tooltip.h"
#include "ui/views/widget/tooltip_manager.h"
@@ -97,7 +97,7 @@ aura::Window* GetTooltipTarget(const ui::MouseEvent& event,
gfx::Point screen_loc(event.location());
aura::client::GetScreenPositionClient(event_target->GetRootWindow())->
ConvertPointToScreen(event_target, &screen_loc);
- gfx::Screen* screen = gfx::Screen::GetScreen();
+ display::Screen* screen = display::Screen::GetScreen();
aura::Window* target = screen->GetWindowAtScreenPoint(screen_loc);
if (!target)
return NULL;
@@ -203,8 +203,8 @@ void TooltipController::OnMouseEvent(ui::MouseEvent* event) {
case ui::ET_MOUSE_DRAGGED: {
curr_mouse_loc_ = event->location();
aura::Window* target = NULL;
// Avoid a call to gfx::Screen::GetWindowAtScreenPoint() since it can be
// very expensive on X11 in cases when the tooltip is hidden anyway.
if (tooltips_enabled_ &&
!aura::Env::GetInstance()->IsMouseButtonDown() &&
!IsDragDropInProgress()) {
@@ -203,8 +203,8 @@ void TooltipController::OnMouseEvent(ui::MouseEvent* event) {
curr_mouse_loc_ = event->location();
aura::Window* target = NULL;
- // Avoid a call to gfx::Screen::GetWindowAtScreenPoint() since it can be
- // very expensive on X11 in cases when the tooltip is hidden anyway.
+ // Avoid a call to display::Screen::GetWindowAtScreenPoint() since it can
+ // be very expensive on X11 in cases when the tooltip is hidden anyway.
if (tooltips_enabled_ &&
!aura::Env::GetInstance()->IsMouseButtonDown() &&
« no previous file with comments | « ui/views/corewm/tooltip_aura.cc ('k') | ui/views/corewm/tooltip_controller_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698